@@ -1,10 +1,10 @@
 #' Summary of multi-analysis object
 #' 
-#' Provides asummary of the fitted detection probability model
+#' Provides a summary of the fitted detection probability model
 #' parameters, model selection criterion, and optionally abundance in the
 #' covered (sampled) region and its standard error for all species.
 #' 
-#' @export summary ma.unid
+#' @export
 #' @method summary ma.unid
 #' @aliases summary.ma.unid
 #' @param object an object of class \code{ma.unid} 
@@ -40,7 +40,7 @@ summary.ma.unid <- function(object, species = NULL, ...){
       selected <- FALSE
       if(!is.null(object$ddf[[model.names[m]]]$ds.param)){
         cat("\nParameter estimates (dsmodel):\n")
-        if(class(object$ddf[[model.names[m]]]$ds.param) == "matrix"){
+        if("matrix" %in% class(object$ddf[[model.names[m]]]$ds.param)){
           param.estimates <- apply(object$ddf[[model.names[m]]]$ds.param, 2, mean)
           param.se <- apply(object$ddf[[model.names[m]]]$ds.param, 2, sd)
           print(array(c(param.estimates, param.se), dim=c(length(param.estimates),2), dimnames=list(dimnames(object$ddf[[model.names[m]]]$ds.param)[[2]], c("Estimate", "se"))))
@@ -55,7 +55,7 @@ summary.ma.unid <- function(object, species = NULL, ...){
       }
       if(!is.null(object$ddf[[model.names[m]]]$mr.param)){
         cat("\nParameter estimates (mrmodel):\n")
-        if(class(object$ddf[[model.names[m]]]$mr.param) == "matrix"){
+        if("matrix" %in% class(object$ddf[[model.names[m]]]$mr.param)){
           param.estimates <- apply(object$ddf[[model.names[m]]]$mr.param, 2, mean)
           param.se <- apply(object$ddf[[model.names[m]]]$mr.param, 2, sd)
           print(array(c(param.estimates, param.se), dim=c(length(param.estimates),2), dimnames=list(dimnames(object$ddf[[model.names[m]]]$mr.param)[[2]], c("Estimate", "se"))))
